@@ -38,7 +38,14 @@ def file2speech(fileName, chn=1, sro=None, start=0, end=-1):
             idx2 = int(end * sr)            
         if idx1 > 0 or idx2 < len(y):
             y = y[idx1:idx2]
-        SpeechObject = SpeechAudio('signal', y.astype(float), 'sampling_frequency', sr)
+        try:
+            SpeechObject = SpeechAudio('signal', y.astype(float), 
+                                       'sampling_frequency', sr)
+        except:
+            SpeechObject = SpeechAudio('signal', np.float32(y), 
+                                       'sampling_frequency', sr)
+        del y
+            
         if sro is not None:
             if sr != sro:
                 SpeechObject.speechresample(sro)
