@@ -265,10 +265,10 @@ class VtNetwork:
                 isSubGlott = True
                 idxSubGlott.append(k)
 
-        if idxChink == []:
-            idxChink = None
-        if idxSubGlott == []:
-            idxSubGlott = None
+        # if idxChink == []:
+        #     idxChink = None
+        # if idxSubGlott == []:
+        #     idxSubGlott = None
 
         self.whereChink = idxChink
         self.whereSubGlott = idxSubGlott
@@ -532,12 +532,12 @@ class VtNetwork:
                 po = Ut[-1-chbool]
         else:
             GSF = np.linalg.solve(Wont, Ft)  # rearrange the system to solve Ug
-            F11 = GSF[0]
+            F11 = GSF[0][0]
             GSi = np.linalg.inv(Wont)
             a2 = -a_eq*GSi[0, 0]
             if a2 != 0:
                 a = solve_pol_2(a2, 1, -F11)
-            else:
+            else:                
                 a = F11
             Ug = np.max([a, 0]) # If the solution is negative, keep 0.
             Ft2 = Ft[1:]
@@ -810,6 +810,7 @@ class VtNetwork:
                oscill_tmp.fundamental_frequency = ssg.resample(oscill_tmp.fundamental_frequency, npts)
                oscill_tmp.low_frequency_abduction = ssg.resample(oscill_tmp.low_frequency_abduction, npts)
                oscill_tmp.partial_abduction = ssg.resample(oscill_tmp.partial_abduction, npts)
+               oscill_tmp.oscillation_factor = ssg.resample(oscill_tmp.oscillation_factor, npts)
                oscill_tmp.output_length = ssg.resample(oscill_tmp.output_length, npts)
                if kOscill == self.whereGlott:
                    oscill_tmp.DC_vector = ssg.resample(oscill_tmp.DC_vector, npts)
@@ -819,19 +820,17 @@ class VtNetwork:
         """ Time-domain speech synthesis. The vocal tract is modeled as a waveguide
         network. The acoustic source is a 2x2 mass model of the
         vocal folds."""
-
+        # import warnings
+        # warnings.filterwarnings("ignore", category=RuntimeWarning)
         if Const is None:
             Const = timestruct()
-
         chbool, sgbool, ich, isg = self.searchchinkandsubglott()
         isGlott, isSupOscill, idxGlott, idxSupOscill = self.searchoscillators()
         if isSupOscill:
             nSupOscill = len(idxSupOscill)
-
         ##### Special objects
         OralTract = self.waveguide[0]
         numIter = OralTract.area_function.area.shape[1]
-
         if isGlott:
             objGlottis = self.oscillators[idxGlott[0]]
         else:
@@ -859,7 +858,6 @@ class VtNetwork:
             aChink = 0
             if isGlott:
                 objGlottis.partial_abduction = np.zeros(numIter)
-
         Nx = self.computenumtubes()
         nPipe = len(Nx)
         self.initnetwork()
@@ -1003,7 +1001,6 @@ class VtNetwork:
 
                     ii = np.argwhere(cp[0, :] == lat)
                     af_main[cp[1, ii[0]]:cp[1, ii[1]]] += af[lat].A[:, k]
-
             if isGlott:
                 objGlottis.updateimpedance(Const, aChink, ain, ac[k], lc)
                 Lg = objGlottis.inductance
@@ -1021,7 +1018,6 @@ class VtNetwork:
             # if (kpc >= 10*kwb and Const.dispcomp):
             #     print('Completion: ' + str(10*kwb) + ' %')
             #     kwb += 1
-
             for kpipe in range(nPipe): # Electric components of each pipe
                 wvg_tmp = self.waveguide[kpipe]
 
@@ -1035,7 +1031,6 @@ class VtNetwork:
 
                 isSub = wvg_tmp.check_instance('SubGlottalTract')
                 wvg_tmp.time_acoustics.acou2elec(Const, uim1, Aglot, isSub)
-
                 namp = Fric_Amp
                 if kpipe == 0:
                     if isGlott and chbool and namp > 0:
@@ -1070,7 +1065,6 @@ class VtNetwork:
                     wvg_tmp.time_acoustics.elements.Lj *= 2 / (Const.rmlt / 4)
                 if isGlott and chbool and namp:
                     wvg_tmp.computenoise(Const, namp, Udc, Aglot)
-
             if isGlott or isSupOscill:
                 for k_oscill in range(len(self.oscillators)):
                     self.oscillators[k_oscill].updateparam(Const)
@@ -1086,7 +1080,6 @@ class VtNetwork:
                 ot_ta_e.Rj[0] + 2 * (np.sum(Lg) + ot_ta_e.Lj[0]) / T + ot_ta_e.Rcm[0]
             OralTract.glottal_inductance = np.sum(objGlottis.inductance)
             OralTract.glottal_bernoulli = np.sum(objGlottis.bernoulli)
-
             self.esmfmatrix(Const.T)
             try:
                 self.esmfmtxsolver(objGlottis.isContact, Const.T)
@@ -1125,7 +1118,7 @@ class VtNetwork:
                         objSup.appliedforce(Const)
                         objSup.updatemassposition(Const)
                     else:
-                        objSup.updatemassishiflan(Const);
+                        objSup.updatemassishiflan(Const)
                     if objSup.num_oscillators == 1:
                         objSup.mass_position[0, :] = 0
                         objSup.mass_position_nm1[0, :] = 0
@@ -1134,6 +1127,35 @@ class VtNetwork:
 
         return self.pressure_radiated
 
+    def inputtrim(self, start_time=0, end_time=None):
+        sr = self.simulation_frequency
+        
+        psub = self.subglottal_control
+        MOT = self.waveguide[0]
+        nb_tubes, nb_frame = MOT.area_function.area.shape
+        phl = self.phonetic_label
+        inst = self.phonetic_instant
+        
+        if end_time is not None:
+            end_idx = int(end_time * sr)
+        else:
+            end_idx = nb_frame
+        start_idx = int(start_time * sr)
+        
+        if end_idx < nb_frame:
+            self.subglottal_control = self.subglottal_control[start_idx:end_idx]
+            for wvg in self.waveguide:
+                wvg.area_function.area = wvg.area_function.area[:, start_idx:end_idx]
+                wvg.area_function.length = wvg.area_function.length[:, start_idx:end_idx]
+            for osc in self.oscillators:
+                osc.fundamental_frequency = osc.fundamental_frequency[start_idx:end_idx]
+                osc.partial_abduction = osc.partial_abduction[start_idx:end_idx]
+                osc.oscillation_factor = osc.oscillation_factor[start_idx:end_idx]
+            idx = [x for x in range(len(phl)) if inst[x, 0] < end_time and 
+                   inst[x, 0] > start_time]
+            self.phonetic_label = [self.phonetic_label[x] for x in idx]
+            self.phonetic_instant = self.phonetic_instant[idx,:]
+
     def plotinputparameters(self):
         """plot the input parameters of the network"""
 
@@ -1157,6 +1179,10 @@ class VtNetwork:
                            xlabel=None,
                            limx=None,
                            ax_share=None)
+        
+        osc_fact = self.oscillators[0].oscillation_factor
+        addplot(ax, tvec, osc_fact,
+                    color=(0, 0.498, 0))
 
         if chbool:
             Chink = self.waveguide[ich[0]]
