@@ -218,11 +218,11 @@ class VtWaveguide(VtNetwork):
                 idxStart = k-dk
             else:
                 idxStart = 0
-            if k+dk <= nFrame:
+            if k+dk < nFrame:
                 idxEnd = k + dk
             else:
-                idxEnd = nFrame
-
+                idxEnd = nFrame - 1
+            
             bb = np.arange(idxStart, idxEnd+1)
 
             if ic >= 38:
@@ -233,6 +233,7 @@ class VtWaveguide(VtNetwork):
                 hl = ssg.firwin(int(ordl), float(fpeak/fny))
 
             Wb = W[idxAct, bb]
+
             if ic >= 38:
                 Wb = ssg.lfilter(Const.hld2, 1, Wb)
             else:
@@ -325,6 +326,7 @@ class VtWaveguide(VtNetwork):
 
         P = np.zeros((nTube+1, nFrame))
         U = np.zeros((nTube+1, nFrame))
+        np.random.seed(100)
         W = np.random.randn(nTube+1, nFrame)
 
         if isinstance(self, GlottalChink):
